=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2011-01-20 23:35:57 +0000
+++ bzrlib/hooks.py	2011-01-22 23:27:17 +0000
@@ -231,7 +231,8 @@
         should describe the recommended replacement hook to register for.
     """
 
-    def __init__(self, name, doc, introduced, deprecated):
+    def __init__(self, name, doc, introduced, deprecated=None, module=None,
+                 member_name=None):
         """Create a HookPoint.
 
         :param name: The name of the hook, for clients to use when registering.
@@ -239,12 +240,18 @@
         :param introduced: When the hook was introduced (e.g. (0, 15)).
         :param deprecated: When the hook was deprecated, None for
             not-deprecated.
+        :param module: The module from which this hook point should be loaded
+            (used for lazy hooks)
+        :param member_name: Name under which these hook points will be available.
+            (used for lazy hooks)
         """
         self.name = name
         self.__doc__ = doc
         self.introduced = introduced
         self.deprecated = deprecated
         self._direct_callbacks = []
+        self._module = module
+        self._member_name = member_name
 
     def docs(self):
         """Generate the documentation for this HookPoint.
@@ -298,8 +305,9 @@
 
     def _get_callbacks(self):
         ret = list(self._direct_callbacks)
-        ret += _lazy_hooks[
-            (self.__module__, self.__class__.__name__, self.name)]
+        if self._module:
+            ret += _lazy_hooks[
+                (self._module, self._member_name, self.name)]
         return ret
 
     def __iter__(self):

=== modified file 'bzrlib/tests/test_hooks.py'
--- bzrlib/tests/test_hooks.py	2011-01-20 21:38:15 +0000
+++ bzrlib/tests/test_hooks.py	2011-01-22 23:27:17 +0000
@@ -123,10 +123,11 @@
         set_rh = lambda: None
         install_lazy_named_hook('bzrlib.tests.test_hooks',
             'TestHooks.hooks', 'set_rh', set_rh, "demo")
-        self.assertEquals([(set_rh, "demo")],
-            _lazy_hooks[
-                ('bzrlib.tests.test_hooks', 'TestHooks.hooks', 'set_rh')])
-        self.assertEqual("demo", self.hooks.get_hook_name(set_rh))
+        set_rh_lazy_hooks = _lazy_hooks[
+            ('bzrlib.tests.test_hooks', 'TestHooks.hooks', 'set_rh')]
+        self.assertEquals(1, len(set_rh_lazy_hooks))
+        self.assertEquals(set_rh, set_rh_lazy_hooks[0][0].get_obj())
+        self.assertEquals("demo", set_rh_lazy_hooks[0][1])
 
     set_rh = lambda: None
 

